#!/usr/bin/python
# -*- coding: utf-8 -*-
import logging
import time

from logger import Logger
from singleton import Singleton
import bottle
import json
import os


class IssuanceCard:
    __metaclass__ = Singleton

    def __init__(self):
        self.log = Logger()
        self.cases = {}

    def registerRoutes(self, servicestub):
        self.log.info(u'Регистрация сервиса onlinecheck')
        self.__updateCases()

        servicestub.route('/onlinechecks/<checkId>', method='GET', callback=self.onlinechecks)
        servicestub.route('/onlinechecks/<checkId>', method='PUT', callback=self.changestatus)

    def onlinechecks(self, checkId=''):
        self.__updateCases()
        self.log.info(u"Запрос чека: '%s'" % checkId)
        methodPath = '/onlinechecks/' + checkId
        self.log.info(methodPath)

        return self.__getResult(methodPath)

    def changestatus(self, checkId=''):
        self.__updateCases()
        self.log.info(u"Изменение статуса чека: '%s'" % checkId)
        methodPath = '/onlinechecks/' + checkId
        self.log.info(methodPath)

        return self.__getResult(methodPath)

    def __getResult(self, methodPath):
        if methodPath not in self.cases:
            raise bottle.HTTPError(400, u'Путь "%s" не существует' % methodPath)

        body = json.dumps(self.cases[methodPath].get('response'))
        time.sleep(self.cases[methodPath].get('timeout', 0))

        response = bottle.HTTPResponse(status=200, body=body)
        response.add_header("Content-Type", "application/json")
        return response

    def __updateCases(self):
        try:
            with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'onlinecheck.json'), 'r') as cases:
                self.cases = json.load(cases, encoding='utf-8')
        except Exception as e:
            self.log.error(str(e))


instance = IssuanceCard()
